Struct openlimits_nash::Nash [−][src]
pub struct Nash {
pub transport: Client,
pub exchange_info: ExchangeInfo,
}Expand description
This struct is the main struct of this module and it is used for communications with the nash openlimits-exchange
Fields
transport: Clientexchange_info: ExchangeInfoImplementations
pub fn convert_limit_order(
req: &OpenLimitOrderRequest,
buy_or_sell: BuyOrSell
) -> LimitOrderRequest